Computes the mass ratio of water uptake to substrate uptake (i.e. mass uptake of water divided by total mass uptake)
waterUptakeRatio(microbeNames, stoichiom, Rtype, numPaths)Vector of strings which contains the names of the microbial groups in the system e.g. c('Bacteroides','Acetogens')
Array: stoichiom[gname,resName,pathName]
Resource type array: Rtype[gname,resName,pathName]
Named vector. Number of paths for each microbial group
water mass ratio matrix [gname,pathName] with names.